@@ -1,5 +1,8 @@
 package DBIx::DataModel::Meta;
 
+use strict;
+use warnings;
+
 1;
 
 __END__
